@@ -1,7 +1,6 @@
 import asyncio
 import logging
 import traceback
-from typing import Any
 
 import discord
 from discord.ext import commands
@@ -21,12 +20,14 @@ sonarr = Sonarr(config["sonarr"]["url"], config["sonarr"]["api_key"])
 
 
 @bot.check
-async def check_channel(ctx: commands.Context[Any]) -> bool:
+async def check_channel(ctx: commands.Context[commands.Bot]) -> bool:
     return ctx.channel.id == config["discord"]["channel_id"]
 
 
 @bot.event
-async def on_command_error(ctx: commands.Context[Any], error: commands.CommandError) -> None:
+async def on_command_error(
+    ctx: commands.Context[commands.Bot], error: commands.CommandError
+) -> None:
     match error:
         case commands.CommandNotFound() | commands.CheckFailure():
             pass
@@ -63,13 +64,13 @@ async def on_ready() -> None:
 
 
 @bot.before_invoke
-async def before_invoke(ctx: commands.Context[Any]) -> None:
+async def before_invoke(ctx: commands.Context[commands.Bot]) -> None:
     logger.info(f"got command from {ctx.message.author}: {ctx.message.content}")
 
 
 @bot.command(name="downloads", aliases=["queue", "q"], help="see the status of movie downloads")
 @commands.cooldown(1, 10)
-async def downloads_cmd(ctx: commands.Context[Any]) -> None:
+async def downloads_cmd(ctx: commands.Context[commands.Bot]) -> None:
     async with ctx.typing():
         queue = radarr.get_downloads() + sonarr.get_downloads()
 
@@ -84,7 +85,7 @@ async def downloads_cmd(ctx: commands.Context[Any]) -> None:
 
 @bot.command(name="quota", help="see your used space on the plex")
 @commands.cooldown(1, 60, commands.BucketType.user)
-async def quota_cmd(ctx: commands.Context[Any]) -> None:
+async def quota_cmd(ctx: commands.Context[commands.Bot]) -> None:
     async with ctx.typing():
         used = (
             radarr.get_quota_amount(ctx.message.author.id)
@@ -98,17 +99,14 @@ async def quota_cmd(ctx: commands.Context[Any]) -> None:
 
         pct = used / maximum * 100 if maximum != 0 else 100
 
-        msg = (
-            f"you have added {used:.2f}/{maximum:.2f} GB ({pct:.1f}%) of useless crap"
-            " to the plex"
-        )
+        msg = f"you have added {used:.2f}/{maximum:.2f} GB ({pct:.1f}%) of useless crap to the plex"
 
     await reply(ctx.message, msg)
 
 
 @bot.command(name="quotas", help="see everyone's used space on the plex")
 @commands.cooldown(1, 60)
-async def quotas_cmd(ctx: commands.Context[Any]) -> None:
+async def quotas_cmd(ctx: commands.Context[commands.Bot]) -> None:
     if "quotas" not in config["discord"]:
         await reply(ctx.message, "quotas are not implemented here")
         return
@@ -139,7 +137,7 @@ async def quotas_cmd(ctx: commands.Context[Any]) -> None:
 
 @bot.command(name="addtag", help="add a user tag")
 @commands.has_role("plex-admin")
-async def addtag_cmd(ctx: commands.Context[Any], name: str, user: discord.Member) -> None:
+async def addtag_cmd(ctx: commands.Context[commands.Bot], name: str, user: discord.Member) -> None:
     tag = f"{name}: {user.id}"
 
     radarr.create_tag(tag)
