@@ -1,6 +1,5 @@
 import asyncio
 import logging
-from typing import Any
 
 from discord.ext import commands
 
@@ -18,7 +17,7 @@ class MovieCog(commands.Cog):
         self.radarr = Radarr(config["radarr"]["url"], config["radarr"]["api_key"])
 
     @commands.command(name="addmovie", help="add a movie to the plex")
-    async def addmovie_cmd(self, ctx: commands.Context[Any], *, query: str = "") -> None:
+    async def addmovie_cmd(self, ctx: commands.Context[commands.Bot], *, query: str = "") -> None:
         if not query:
             await reply(ctx.message, "usage: !addmovie KEYWORDS...")
             return
@@ -71,7 +70,7 @@ class MovieCog(commands.Cog):
             await ctx.send(f"hey <@!{config['discord']['admin_id']}> get this guy a tag")
 
     @commands.command(name="delmovie", help="delete a movie from the plex")
-    async def delmovie_cmd(self, ctx: commands.Context[Any], *, query: str = "") -> None:
+    async def delmovie_cmd(self, ctx: commands.Context[commands.Bot], *, query: str = "") -> None:
         if not query:
             await reply(ctx.message, "usage: !delmovie KEYWORDS...")
             return
