@@ -4,7 +4,7 @@ from wi1_bot.arr import Radarr, Sonarr
 from wi1_bot.config import config
 
 
-def main():
+def main() -> None:
     parser = argparse.ArgumentParser()
 
     parser.add_argument("nickname")
